diff --git a/README.md b/README.md
index 7440ef54..444cc85d 100644
--- a/README.md
+++ b/README.md
@@ -82,7 +82,7 @@ too - it's ignored in the kickstart repo to make maintenance easier, but it's
Linux and Mac
```sh
-git clone https://github.com/nvim-lua/kickstart.nvim.git "${XDG_CONFIG_HOME:-$HOME/.config}"/nvim
+git clone git@github.com:acpaul473/kickstart.nvim.git "${XDG_CONFIG_HOME:-$HOME/.config}"/nvim
```
@@ -262,7 +262,7 @@ available methods being discussed
Bob
[Bob](https://github.com/MordechaiHadad/bob) is a Neovim version manager for
-all plattforms. Simply install
+all platforms. Simply install
[rustup](https://rust-lang.github.io/rustup/installation/other.html),
and run the following commands:
diff --git a/lua/kickstart/plugins/gitsigns.lua b/lua/kickstart/plugins/gitsigns.lua
index f0137084..5f5652f9 100644
--- a/lua/kickstart/plugins/gitsigns.lua
+++ b/lua/kickstart/plugins/gitsigns.lua
@@ -5,56 +5,54 @@
---@module 'lazy'
---@type LazySpec
return {
- {
- 'lewis6991/gitsigns.nvim',
- ---@module 'gitsigns'
- ---@type Gitsigns.Config
- ---@diagnostic disable-next-line: missing-fields
- opts = {
- on_attach = function(bufnr)
- local gitsigns = require 'gitsigns'
+ 'lewis6991/gitsigns.nvim',
+ ---@module 'gitsigns'
+ ---@type Gitsigns.Config
+ ---@diagnostic disable-next-line: missing-fields
+ opts = {
+ on_attach = function(bufnr)
+ local gitsigns = require 'gitsigns'
- local function map(mode, l, r, opts)
- opts = opts or {}
- opts.buffer = bufnr
- vim.keymap.set(mode, l, r, opts)
+ local function map(mode, l, r, opts)
+ opts = opts or {}
+ opts.buffer = bufnr
+ vim.keymap.set(mode, l, r, opts)
+ end
+
+ -- Navigation
+ map('n', ']c', function()
+ if vim.wo.diff then
+ vim.cmd.normal { ']c', bang = true }
+ else
+ gitsigns.nav_hunk 'next'
end
+ end, { desc = 'Jump to next git [c]hange' })
- -- Navigation
- map('n', ']c', function()
- if vim.wo.diff then
- vim.cmd.normal { ']c', bang = true }
- else
- gitsigns.nav_hunk 'next'
- end
- end, { desc = 'Jump to next git [c]hange' })
+ map('n', '[c', function()
+ if vim.wo.diff then
+ vim.cmd.normal { '[c', bang = true }
+ else
+ gitsigns.nav_hunk 'prev'
+ end
+ end, { desc = 'Jump to previous git [c]hange' })
- map('n', '[c', function()
- if vim.wo.diff then
- vim.cmd.normal { '[c', bang = true }
- else
- gitsigns.nav_hunk 'prev'
- end
- end, { desc = 'Jump to previous git [c]hange' })
-
- -- Actions
- -- visual mode
- map('v', 'hs', function() gitsigns.stage_hunk { vim.fn.line '.', vim.fn.line 'v' } end, { desc = 'git [s]tage hunk' })
- map('v', 'hr', function() gitsigns.reset_hunk { vim.fn.line '.', vim.fn.line 'v' } end, { desc = 'git [r]eset hunk' })
- -- normal mode
- map('n', 'hs', gitsigns.stage_hunk, { desc = 'git [s]tage hunk' })
- map('n', 'hr', gitsigns.reset_hunk, { desc = 'git [r]eset hunk' })
- map('n', 'hS', gitsigns.stage_buffer, { desc = 'git [S]tage buffer' })
- map('n', 'hu', gitsigns.stage_hunk, { desc = 'git [u]ndo stage hunk' })
- map('n', 'hR', gitsigns.reset_buffer, { desc = 'git [R]eset buffer' })
- map('n', 'hp', gitsigns.preview_hunk, { desc = 'git [p]review hunk' })
- map('n', 'hb', gitsigns.blame_line, { desc = 'git [b]lame line' })
- map('n', 'hd', gitsigns.diffthis, { desc = 'git [d]iff against index' })
- map('n', 'hD', function() gitsigns.diffthis '@' end, { desc = 'git [D]iff against last commit' })
- -- Toggles
- map('n', 'tb', gitsigns.toggle_current_line_blame, { desc = '[T]oggle git show [b]lame line' })
- map('n', 'tD', gitsigns.preview_hunk_inline, { desc = '[T]oggle git show [D]eleted' })
- end,
- },
+ -- Actions
+ -- visual mode
+ map('v', 'hs', function() gitsigns.stage_hunk { vim.fn.line '.', vim.fn.line 'v' } end, { desc = 'git [s]tage hunk' })
+ map('v', 'hr', function() gitsigns.reset_hunk { vim.fn.line '.', vim.fn.line 'v' } end, { desc = 'git [r]eset hunk' })
+ -- normal mode
+ map('n', 'hs', gitsigns.stage_hunk, { desc = 'git [s]tage hunk' })
+ map('n', 'hr', gitsigns.reset_hunk, { desc = 'git [r]eset hunk' })
+ map('n', 'hS', gitsigns.stage_buffer, { desc = 'git [S]tage buffer' })
+ map('n', 'hu', gitsigns.stage_hunk, { desc = 'git [u]ndo stage hunk' })
+ map('n', 'hR', gitsigns.reset_buffer, { desc = 'git [R]eset buffer' })
+ map('n', 'hp', gitsigns.preview_hunk, { desc = 'git [p]review hunk' })
+ map('n', 'hb', gitsigns.blame_line, { desc = 'git [b]lame line' })
+ map('n', 'hd', gitsigns.diffthis, { desc = 'git [d]iff against index' })
+ map('n', 'hD', function() gitsigns.diffthis '@' end, { desc = 'git [D]iff against last commit' })
+ -- Toggles
+ map('n', 'tb', gitsigns.toggle_current_line_blame, { desc = '[T]oggle git show [b]lame line' })
+ map('n', 'tD', gitsigns.preview_hunk_inline, { desc = '[T]oggle git show [D]eleted' })
+ end,
},
}
diff --git a/lua/kickstart/plugins/indent_line.lua b/lua/kickstart/plugins/indent_line.lua
index 6a95da80..946ac793 100644
--- a/lua/kickstart/plugins/indent_line.lua
+++ b/lua/kickstart/plugins/indent_line.lua
@@ -1,13 +1,13 @@
+-- Add indentation guides even on blank lines
+
---@module 'lazy'
---@type LazySpec
return {
- { -- Add indentation guides even on blank lines
- 'lukas-reineke/indent-blankline.nvim',
- -- Enable `lukas-reineke/indent-blankline.nvim`
- -- See `:help ibl`
- main = 'ibl',
- ---@module 'ibl'
- ---@type ibl.config
- opts = {},
- },
+ 'lukas-reineke/indent-blankline.nvim',
+ -- Enable `lukas-reineke/indent-blankline.nvim`
+ -- See `:help ibl`
+ main = 'ibl',
+ ---@module 'ibl'
+ ---@type ibl.config
+ opts = {},
}
diff --git a/lua/kickstart/plugins/lint.lua b/lua/kickstart/plugins/lint.lua
index 7054023c..326fc3f6 100644
--- a/lua/kickstart/plugins/lint.lua
+++ b/lua/kickstart/plugins/lint.lua
@@ -1,60 +1,59 @@
+-- Linting
+
---@module 'lazy'
---@type LazySpec
return {
+ 'mfussenegger/nvim-lint',
+ event = { 'BufReadPre', 'BufNewFile' },
+ config = function()
+ local lint = require 'lint'
+ lint.linters_by_ft = {
+ markdown = { 'markdownlint' },
+ }
- { -- Linting
- 'mfussenegger/nvim-lint',
- event = { 'BufReadPre', 'BufNewFile' },
- config = function()
- local lint = require 'lint'
- lint.linters_by_ft = {
- markdown = { 'markdownlint' },
- }
+ -- To allow other plugins to add linters to require('lint').linters_by_ft,
+ -- instead set linters_by_ft like this:
+ -- lint.linters_by_ft = lint.linters_by_ft or {}
+ -- lint.linters_by_ft['markdown'] = { 'markdownlint' }
+ --
+ -- However, note that this will enable a set of default linters,
+ -- which will cause errors unless these tools are available:
+ -- {
+ -- clojure = { "clj-kondo" },
+ -- dockerfile = { "hadolint" },
+ -- inko = { "inko" },
+ -- janet = { "janet" },
+ -- json = { "jsonlint" },
+ -- markdown = { "vale" },
+ -- rst = { "vale" },
+ -- ruby = { "ruby" },
+ -- terraform = { "tflint" },
+ -- text = { "vale" }
+ -- }
+ --
+ -- You can disable the default linters by setting their filetypes to nil:
+ -- lint.linters_by_ft['clojure'] = nil
+ -- lint.linters_by_ft['dockerfile'] = nil
+ -- lint.linters_by_ft['inko'] = nil
+ -- lint.linters_by_ft['janet'] = nil
+ -- lint.linters_by_ft['json'] = nil
+ -- lint.linters_by_ft['markdown'] = nil
+ -- lint.linters_by_ft['rst'] = nil
+ -- lint.linters_by_ft['ruby'] = nil
+ -- lint.linters_by_ft['terraform'] = nil
+ -- lint.linters_by_ft['text'] = nil
- -- To allow other plugins to add linters to require('lint').linters_by_ft,
- -- instead set linters_by_ft like this:
- -- lint.linters_by_ft = lint.linters_by_ft or {}
- -- lint.linters_by_ft['markdown'] = { 'markdownlint' }
- --
- -- However, note that this will enable a set of default linters,
- -- which will cause errors unless these tools are available:
- -- {
- -- clojure = { "clj-kondo" },
- -- dockerfile = { "hadolint" },
- -- inko = { "inko" },
- -- janet = { "janet" },
- -- json = { "jsonlint" },
- -- markdown = { "vale" },
- -- rst = { "vale" },
- -- ruby = { "ruby" },
- -- terraform = { "tflint" },
- -- text = { "vale" }
- -- }
- --
- -- You can disable the default linters by setting their filetypes to nil:
- -- lint.linters_by_ft['clojure'] = nil
- -- lint.linters_by_ft['dockerfile'] = nil
- -- lint.linters_by_ft['inko'] = nil
- -- lint.linters_by_ft['janet'] = nil
- -- lint.linters_by_ft['json'] = nil
- -- lint.linters_by_ft['markdown'] = nil
- -- lint.linters_by_ft['rst'] = nil
- -- lint.linters_by_ft['ruby'] = nil
- -- lint.linters_by_ft['terraform'] = nil
- -- lint.linters_by_ft['text'] = nil
-
- -- Create autocommand which carries out the actual linting
- -- on the specified events.
- local lint_augroup = vim.api.nvim_create_augroup('lint', { clear = true })
- vim.api.nvim_create_autocmd({ 'BufEnter', 'BufWritePost', 'InsertLeave' }, {
- group = lint_augroup,
- callback = function()
- -- Only run the linter in buffers that you can modify in order to
- -- avoid superfluous noise, notably within the handy LSP pop-ups that
- -- describe the hovered symbol using Markdown.
- if vim.bo.modifiable then lint.try_lint() end
- end,
- })
- end,
- },
+ -- Create autocommand which carries out the actual linting
+ -- on the specified events.
+ local lint_augroup = vim.api.nvim_create_augroup('lint', { clear = true })
+ vim.api.nvim_create_autocmd({ 'BufEnter', 'BufWritePost', 'InsertLeave' }, {
+ group = lint_augroup,
+ callback = function()
+ -- Only run the linter in buffers that you can modify in order to
+ -- avoid superfluous noise, notably within the handy LSP pop-ups that
+ -- describe the hovered symbol using Markdown.
+ if vim.bo.modifiable then lint.try_lint() end
+ end,
+ })
+ end,
}
diff --git a/init.lua b/init.lua
index 330e54b4..2bbac6fb 100644
--- a/init.lua
+++ b/init.lua
@@ -361,7 +361,7 @@ require('lazy').setup({
spec = {
{ 's', group = '[S]earch', mode = { 'n', 'v' } },
{ 't', group = '[T]oggle' },
- { 'h', group = 'Git [H]unk', mode = { 'n', 'v' } },
+ { 'h', group = 'Git [H]unk', mode = { 'n', 'v' } }, -- Enable gitsigns recommended keymaps first
{ 'gr', group = 'LSP Actions', mode = { 'n' } },
},
},
@@ -543,9 +543,6 @@ require('lazy').setup({
-- Useful status updates for LSP.
{ 'j-hui/fidget.nvim', opts = {} },
-
- -- Allows extra capabilities provided by blink.cmp
- 'saghen/blink.cmp',
},
config = function()
-- Brief aside: **What is LSP?**
@@ -965,7 +962,7 @@ require('lazy').setup({
-- require 'kickstart.plugins.lint',
-- require 'kickstart.plugins.autopairs',
-- require 'kickstart.plugins.neo-tree',
- -- require 'kickstart.plugins.gitsigns', -- adds gitsigns recommend keymaps
+ -- require 'kickstart.plugins.gitsigns', -- adds gitsigns recommended keymaps
-- NOTE: The import below can automatically add your own plugins, configuration, etc from `lua/custom/plugins/*.lua`
-- This is the easiest way to modularize your config.